/*
  ==============================================================================

   Demonstration "Hello World" application in JUCE
   Copyright 2008 by Julian Storer.

  ==============================================================================
*/

#include "../JuceLibraryCode/JuceHeader.h"
#include "config.h"
#include "Common/editor.h"

//==============================================================================
/**
    This is the top-level window that we'll pop up. Inside it, we'll create and
    show a component from the MainComponent.cpp file (you can open this file using
    the Jucer to edit it).
*/
class MainWindow  : public DocumentWindow
{
public:
    //==============================================================================
	MainWindow()
        : DocumentWindow (_SW_NAME_,
                          Colours::lightgrey,
                          DocumentWindow::minimiseButton|DocumentWindow::closeButton,
                          true)
    {
        // Create an instance of our main content component, and add it
        // to our window.

    	editor* const contentComponent = new editor();

        setContentComponent (contentComponent, true, true);

        centreWithSize (getWidth(), getHeight());

        setVisible (true);
    }

    ~MainWindow()
    {
        // (the content component will be deleted automatically, so no need to do it here)
    }

    //==============================================================================
    void closeButtonPressed()
    {
        // When the user presses the close button, we'll tell the app to quit. This
        // window will be deleted by our HelloWorldApplication::shutdown() method
        //
        JUCEApplication::quit();
    }
};

//==============================================================================
/** This is the application object that is started up when Juce starts. It handles
    the initialisation and shutdown of the whole application.
*/
class BIT_Application : public JUCEApplication
{
public:
    //==============================================================================
    BIT_Application()
        : mainWindow (0)
    {
    }

    ~BIT_Application()
    {
    }

    //==============================================================================
    void initialise (const String& commandLine)
    {
        // For this demo, we'll just create the main window...
    	mainWindow = new MainWindow();

        /*  ..and now return, which will fall into to the main event
            dispatch loop, and this will run until something calls
            JUCEAppliction::quit().

            In this case, JUCEAppliction::quit() will be called by the
            hello world window being clicked.
        */
    }

    void shutdown()
    {
        // This method is where you should clear-up your app's resources..

        // The helloWorldWindow variable is a ScopedPointer, so setting it to a null
        // pointer will delete the window.
    	mainWindow = 0;
    }

    //==============================================================================
    const String getApplicationName()
    {
        return "BIT MESSAGE SIMULATOR";
    }

    const String getApplicationVersion()
    {
        // The ProjectInfo::versionString value is automatically updated by the Jucer, and
        // can be found in the JuceHeader.h file that it generates for our project.
        return ProjectInfo::versionString;
    }

    bool moreThanOneInstanceAllowed()
    {
        return true;
    }

    void anotherInstanceStarted (const String& commandLine)
    {
    }

private:
    ScopedPointer<MainWindow> mainWindow;
};


//==============================================================================
// This macro creates the application's main() function..
START_JUCE_APPLICATION (BIT_Application)
